#include <inttypes.h>

typedef struct {
    int32_t totalLength;
    uint32_t h[5];
    uint32_t w[80];
} SHS_CTX;

unsigned char *qshs(unsigned char *s, int32_t n);
#ifdef SOLARIS2X
#define bzero(b, l)             memset(b, 0, l)
#define bcopy(s, d, l)          memcpy(d, s, l)
#define bcmp(s, d, l)           (memcmp(s, d, l)? 1 : 0)
#endif

